"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterTakenUsernames = void 0;
const mojangApi_1 = require("./mojang/mojangApi");
const axios_1 = require("axios");
const sleep = async (ms) => {
    await new Promise(resolve => setTimeout(resolve, ms));
};
/**
 * Filters the available usernames by consuming mojangs API
 * @param usernames List of usernames to Check
 * @return All usernames that are not taken yet
 */
const filterTakenUsernames = async (usernames) => {
    const availableNames = [];
    let index = 0;
    for (const username of usernames) {
        try {
            if (index % 2 == 0) {
                await sleep(1000);
            }
            if (await isUsernameAvailable(username)) {
                availableNames.push(username);
            }
            index++;
        }
        catch (e) {
            if (e instanceof axios_1.AxiosError) {
                console.error(e.response.data.error);
                console.error(e.response.data.errorMessage);
                await sleep(5000);
                usernames.push(username);
            }
        }
    }
    return availableNames;
};
exports.filterTakenUsernames = filterTakenUsernames;
const isUsernameAvailable = async (username) => {
    console.log("req");
    const profile = await (0, mojangApi_1.getProfile)(username);
    return profile == null;
};
//# sourceMappingURL=usernameScanner.js.map