#!/usr/bin/env node

import {isUsernameValid} from "./mojang/mojangApi";
import {parseList} from "./parsing/listParser";
import * as fs from "fs";
import {filterTakenUsernames} from "./usernameScanner";
import * as os from "os";

const main = async () => {
  if (process.argv.length < 3) {
    console.error("Expected Input Filename. Usage: mc-username-checker <input-file> [output-file]")
    process.exit(1)
  }

  const inputFileName = process.argv[2]
  const outputFileName = process.argv[3] ?? "out.txt"

  const input = fs.readFileSync(inputFileName).toString()

  const usernames = parseList(input)
    .map(s => s.trim())
    .filter(username => {
      if (!isUsernameValid(username)) {
        console.log(`Invalid Username: ${username}`)
        return false
      }
      return true
    })

  const availableUsernames = await filterTakenUsernames(usernames)
  fs.writeFileSync(outputFileName, availableUsernames.join(os.EOL))
  console.log(`Saved available usernames in ${outputFileName}`)
}

main()