import {getProfile} from "./mojang/mojangApi";
import {AxiosError} from "axios";

const sleep = async (ms: number) => {
  await new Promise(resolve => setTimeout(resolve, ms))
};

/**
 * Filters the available usernames by consuming mojangs API
 * @param usernames List of usernames to Check
 * @return All usernames that are not taken yet
 */
export const filterTakenUsernames = async (usernames: Array<string>): Promise<Array<String>> => {
  const availableNames = []
  let index = 0
  for (const username of usernames) {
    try {
      if (index % 2 == 0) {
        await sleep(1000)
      }
      if (await isUsernameAvailable(username)) {
        availableNames.push(username)
      }
      index++
    } catch (e) {
      if (e instanceof AxiosError) {
        console.error(e.response.data.error)
        console.error(e.response.data.errorMessage)
        await sleep(5000)
        usernames.push(username)
      }
    }

  }
  return availableNames
}

const isUsernameAvailable = async (username: string): Promise<boolean> => {
  const profile = await getProfile(username)
  return profile == null
}